@@ -13,6 +13,8 @@ from datetime import datetime
 from pynmeagps.nmeatypes_core import LA, LN
 import pynmeagps.exceptions as nme
 
+KNOTSCONV = {"MS": 0.5144447324, "FS": 1.68781084, "MPH": 1.15078, "KMPH": 1.852001}
+
 
 def int2hexstr(val: int) -> str:
     """
@@ -181,7 +183,7 @@ def time2utc(times: str) -> datetime.time:
 
     if times == "":
         return ""
-    # TODO not quite right should be decimal secs, not microsecs
+    # TODO check this is correct
     utc = datetime.strptime(times, "%H%M%S.%f")
     return utc.time()
 
@@ -213,7 +215,7 @@ def date2str(dat: datetime.date) -> str:
 def deg2dms(degrees: float, att: str) -> str:
     """
     Convert decimal degrees to degrees minutes seconds string
-    e.g. for display purposes.
+    e.g. '51°20′45.6″N'
 
     :param float degrees: degrees
     :param str att: 'LA' (lat) or 'LN' (lon)
@@ -246,7 +248,7 @@ def deg2dms(degrees: float, att: str) -> str:
 def deg2dmm(degrees: float, att: str) -> str:
     """
     Convert decimal degrees to degrees decimal minutes string
-    e.g. for display purposes.
+    e.g. '51°20.76′S'.
 
     :param float degrees: degrees
     :param str att: 'LA' (lat) or 'LN' (lon)
@@ -265,3 +267,26 @@ def deg2dmm(degrees: float, att: str) -> str:
     else:
         sfx = "N" if att == "LA" else "E"
     return str(int(degrees)) + "\u00b0" + str(round(minutes, 5)) + "\u2032" + sfx
+
+
+def knots2spd(knots: float, unit: str = "MS") -> float:
+    """
+    Convert speed in knots to speed in specified units.
+
+    :param float knots: knots
+    :param unit str: 'MS' (default), 'FS', MPH', 'KMPH'
+    :return: speed in m/s, feet/s, mph or kmph
+    :rtype: float
+
+    """
+
+    try:
+        return knots * KNOTSCONV[unit.upper()]
+    except KeyError as err:
+        raise KeyError(
+            f"Invalid conversion unit {unit.upper()} - must be in {list(KNOTSCONV.keys())}."
+        ) from err
+    except TypeError as err:
+        raise TypeError(
+            f"Invalid knots value {knots} - must be float or integer."
+        ) from err
